/*
 * Copyright (c) 2016 Intel Corporation
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr/kernel.h>

#include <zephyr/pm/device.h>
#include <zephyr/pm/pm.h>
#include <nrfx_spim.h>
#include <zephyr/drivers/gpio.h>
#include <hal/nrf_gpio.h>

#include <zephyr/drivers/spi.h>

/* 1000 msec = 1 sec */
#define SLEEP_TIME_MS   1000

/******************************	SPI *******************************************/

// #define SPI_NODE DT_NODELABEL(SPI_4)
#define SPI_OP  SPI_OP_MODE_MASTER | SPI_WORD_SET(8) | SPI_LINES_SINGLE

#define FLASH_MEM_HOLD_PIN DT_ALIAS(flashholdpin)
#define FLASH_MEM_WP_PIN DT_ALIAS(flashwppin)
const struct gpio_dt_spec FLASH_WP_PIN = GPIO_DT_SPEC_GET(FLASH_MEM_WP_PIN, 
                                                                        gpios);
const struct gpio_dt_spec FLASH_HOLD_PIN = GPIO_DT_SPEC_GET(FLASH_MEM_HOLD_PIN, 
                                                                         gpios);
/******************************END*******************************************/


int main(void)
{
	int ret = 0;

	/***************************spi init**************************************/

	ret = gpio_pin_configure_dt(&FLASH_HOLD_PIN,GPIO_OUTPUT_INACTIVE);
	ret = gpio_pin_configure_dt(&FLASH_WP_PIN,GPIO_OUTPUT_INACTIVE);
	const struct device *spi;
	struct spi_config spi_cfg = {0};

	spi = device_get_binding("SPI_4");
	if (!spi) {
		// printk("Could not find SPI driver\n");
		return;
	}

	spi_cfg.operation = SPI_OP;
	spi_cfg.frequency = 8000000U;
	spi_cfg.slave = 0;

	if (device_is_ready(spi))
    {
		// printk("spi device_is_ready \n");
    }

	uint8_t data  = 0x00;
	struct spi_buf_set pdata;
	struct spi_buf buff;

	buff.buf = &data;
	buff.len = 1;

	pdata.buffers = &buff;
	pdata.count = 1;

	ret = spi_write(spi,&spi_cfg,&pdata);
	printk("spi trx %d \n",ret);


	/***************************END *****************************************/

	while(1)
	{
		k_msleep(2000);	

		/***************************spi-pm-test**************************/

		ret = pm_device_action_run(spi, PM_DEVICE_ACTION_RESUME);
		//write to flash
		ret = spi_write(spi,&spi_cfg,&pdata);		
		k_msleep(3000);	
		ret = pm_device_action_run(spi, PM_DEVICE_ACTION_SUSPEND);
		/*****************************end**********************************/
		

	}

	return 0;
}
